@@ -36,6 +36,9 @@ Q_DECL_EXPORT
 #endif
 int main(int argc, char *argv[])
 {
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+
     QCommandLineParser parser;
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
@@ -95,6 +98,7 @@ int main(int argc, char *argv[])
                      KAboutLicense::GPL,
                      i18n("© 2019 KDE Community"));
     about.addAuthor(i18n("Nicolas Fella"), QString(), QStringLiteral("nicolas.fella@gmx.de"));
+    about.setBugAddress("https://invent.kde.org/utilities/ktrip/-/issues");
     KAboutData::setApplicationData(about);
 
     engine.rootContext()->setContextProperty(QStringLiteral("_aboutData"), QVariant::fromValue(about));
